// Created on: 2000-05-30
// Created by: Sergey MOZOKHIN
// Copyright (c) 2000-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <VrmlAPI.hxx>

#include <TopoDS_Shape.hxx>
#include <VrmlAPI_Writer.hxx>

Standard_Boolean VrmlAPI::Write(const TopoDS_Shape&    aShape,
                                const Standard_CString aFileName,
                                const Standard_Integer aVersion)
{
  VrmlAPI_Writer writer;
  return writer.Write(aShape, aFileName, aVersion);
}
